@@ -20,7 +20,8 @@ struct tpm2_encoder_ctx_st {
 
 static OSSL_FUNC_encoder_newctx_fn tpm2_encoder_newctx;
 static OSSL_FUNC_encoder_freectx_fn tpm2_encoder_freectx;
-static OSSL_FUNC_encoder_encode_fn tpm2_encoder_encode_text;
+static OSSL_FUNC_encoder_encode_fn tpm2_rsa_encoder_encode_text;
+static OSSL_FUNC_encoder_encode_fn tpm2_ec_encoder_encode_text;
 
 static void *
 tpm2_encoder_newctx(void *provctx)
@@ -79,13 +80,13 @@ tpm2_encoder_freectx(void *ctx)
         if ((bout = BIO_new_from_core_bio(ectx->libctx, cout)) == NULL) \
             return 0; \
         if (selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY) { \
-            if (tpm2_##otype##_encode_private_##ostructure##_##oformat) \
+            if (tpm2_##otype##_encode_private_##ostructure##_##oformat != NULL) \
                 ret = tpm2_##otype##_encode_private_##ostructure##_##oformat(ectx, bout, pkey); \
         } else if (selection & OSSL_KEYMGMT_SELECT_PUBLIC_KEY) { \
-            if (tpm2_##otype##_encode_public_##ostructure##_##oformat) \
+            if (tpm2_##otype##_encode_public_##ostructure##_##oformat != NULL) \
                 ret = tpm2_##otype##_encode_public_##ostructure##_##oformat(ectx, bout, pkey); \
         } else if (selection & OSSL_KEYMGMT_SELECT_DOMAIN_PARAMETERS) { \
-            if (tpm2_##otype##_encode_parameters_##ostructure##_##oformat) \
+            if (tpm2_##otype##_encode_parameters_##ostructure##_##oformat != NULL) \
                 ret = tpm2_##otype##_encode_parameters_##ostructure##_##oformat(ectx, bout, pkey); \
         } \
         BIO_free(bout); \
@@ -175,7 +176,8 @@ tpm2_get_rsa_pubkey(const TPM2_PKEY *pkey)
     if (!exponent)
         exponent = 0x10001;
 
-    if (!ASN1_INTEGER_set(tpk->e, exponent))
+    // note the ASN1_INTEGER_set is not reliable for uin32_t on 32-bit machines
+    if (!ASN1_INTEGER_set_uint64(tpk->e, exponent))
         goto error2;
 
     return tpk;
@@ -288,7 +290,7 @@ tpm2_get_x509_rsa_pubkey(const TPM2_PKEY *pkey)
         return NULL;
 
     if ((pubkey = X509_PUBKEY_new()) == NULL) {
-        free(penc);
+        OPENSSL_free(penc);
         return NULL;
     }
 
