@@ -115,12 +115,7 @@ ensure_key_loaded(TPM2_PKEY *pkey)
     {
         r = Esys_LoadExternal(pkey->esys_ctx,
                               ESYS_TR_NONE, ESYS_TR_NONE, ESYS_TR_NONE,
-                              NULL, &pkey->data.pub,
-#ifdef HAVE_TSS2_ESYS3
-                              ESYS_TR_RH_NULL,
-#else
-                              TPM2_RH_NULL,
-#endif
+                              NULL, &pkey->data.pub, ESYS_TR_RH_NULL,
                               &pkey->object);
         TPM2_CHECK_RC(pkey->core, r, TPM2_ERR_CANNOT_LOAD_KEY, return 0);
     }
@@ -289,12 +284,12 @@ get_signature_buffer(const TPMT_SIGNATURE *signature,
         *siglen = strlen;
         if (sig != NULL) {
             if (*siglen > sigsize) {
-                free(str);
+                OPENSSL_free(str);
                 return 0;
             }
             memcpy(sig, str, *siglen);
         }
-        free(str);
+        OPENSSL_free(str);
         return 1;
     } else
         return 0;
@@ -371,7 +366,6 @@ static int
 tpm2_rsa_signature_digest_init(void *ctx, const char *mdname, void *provkey,
                                const OSSL_PARAM params[])
 {
-    TSS2_RC r;
     TPM2_SIGNATURE_CTX *sctx = ctx;
 
     DBG("SIGN DIGEST_INIT rsa MD=%s\n", mdname);
@@ -385,7 +379,6 @@ static int
 tpm2_ecdsa_signature_digest_init(void *ctx, const char *mdname, void *provkey,
                                  const OSSL_PARAM params[])
 {
-    TSS2_RC r;
     TPM2_SIGNATURE_CTX *sctx = ctx;
 
     DBG("SIGN DIGEST_INIT ecdsa MD=%s\n", mdname);
@@ -473,7 +466,6 @@ tpm2_signature_digest_sign(void *ctx, unsigned char *sig, size_t *siglen,
 {
     TSS2_RC r;
     TPM2_SIGNATURE_CTX *sctx = ctx;
-    TPM2B_MAX_BUFFER buffer;
     TPM2B_DIGEST *digest = NULL;
     TPMT_TK_HASHCHECK *validation = NULL;
 
@@ -559,7 +551,7 @@ tpm2_signature_get_ctx_params(void *ctx, OSSL_PARAM params[])
             return 0;
 
         r = OSSL_PARAM_set_octet_string(p, aid, aid_len);
-        free(aid);
+        OPENSSL_free(aid);
         return r;
     }
 
